@@ -1,10 +1,10 @@
-#![cfg_attr(not(std), no_std)]
+#![cfg_attr(not(feature = "std"), no_std)]
 
 #[allow(unused_imports)]
 #[macro_use]
 extern crate alloc;
 
-#[cfg(any(std, test))]
+#[cfg(any(feature = "std", test))]
 #[macro_use]
 extern crate std;
 
@@ -18,6 +18,8 @@ mod node;
 mod set;
 pub mod traits;
 
+pub use result::BitError as BitError;
+
 /// The only error you'll find is `NotFound`.
 #[derive(Debug, Clone, Eq, PartialEq)]
 pub enum HashTrieError {
@@ -28,13 +30,13 @@ pub enum HashTrieError {
 pub use set::HashTrieSet as HashTrieSet;
 pub use map::HashTrieMap as HashTrieMap;
 
-#[cfg(std)]
-pub type DefaultHashTrieSet<V> = set::HashTrieSet<u64, V, std::collections::hash_map::DefaultHasher>;
+#[cfg(any(feature = "std", test))]
+pub type DefaultHashTrieSet<V> = set::HashTrieSet<u64, u32, V, std::collections::hash_map::DefaultHasher>;
 
-#[cfg(std)]
-pub type DefaultHashTrieMap<K, V> = map::HashTrieMap<u64, K, V, std::collections::hash_map::DefaultHasher>;
+#[cfg(any(feature = "std", test))]
+pub type DefaultHashTrieMap<K, V> = map::HashTrieMap<u64, u32, K, V, std::collections::hash_map::DefaultHasher>;
 
-#[cfg(all(std, test))]
+#[cfg(test)]
 mod tests {
     use crate::{DefaultHashTrieMap, DefaultHashTrieSet};
     use alloc::string::String;
@@ -42,8 +44,8 @@ mod tests {
 
     #[test]
     fn std_test() {
-        let _hash_set = DefaultHashTrieSet::<i32>::new().insert(Cow::Owned(42));
-        let _hash_map = DefaultHashTrieMap::<i32, String>::new().insert(Cow::Owned(42), Cow::Owned("Hello, world!".into()));
+        let _hash_set = DefaultHashTrieSet::<i32>::new().insert(Cow::Owned(42), false);
+        let _hash_map = DefaultHashTrieMap::<i32, String>::new().insert(Cow::Owned(42), Cow::Owned("Hello, world!".into()), false);
     }
 
 }
