@@ -16,6 +16,7 @@ pub(crate) struct LNode<V: Value> {
 }
 
 impl<V: Value> LNode<V> {
+    #[must_use]
     pub(super) fn new(value: V, next: LNodeNext<V>) -> Arc<Self> {
         let size = 1 + match &next {
             LNodeNext::L(lnode) => lnode.size,
@@ -28,6 +29,7 @@ impl<V: Value> LNode<V> {
         })
     }
 
+    #[must_use]
     pub(super) fn size(&self) -> usize {
         self.size
     }
@@ -44,7 +46,7 @@ impl<V: Value> LNode<V> {
         }
     }
 
-    pub(super) fn remove<'a, B: Bits, K, H: 'static>(&'a self, key: &K) -> RemoveResult<'a, B, V, H> where V: PartialEq<K> {
+    pub(super) fn remove<'a, H: Hashword, F: Flagword<H>, M: 'static, K>(&'a self, key: &K) -> RemoveResult<'a, H, F, V, M> where V: PartialEq<K> {
         match self.remove_from_lnode(key) {
             LNodeRemoveResult::NotFound => RemoveResult::NotFound,
             LNodeRemoveResult::RemovedL(lnode, reference) => RemoveResult::RemovedL(lnode, reference),
@@ -75,7 +77,7 @@ impl<V: Value> LNode<V> {
     }
 }
 
-pub(super) fn insert<'a, B: Bits, K: 'static, V: Value, C: AsRef<K> + Into<V>, H: HasherBv<B, V>>(this: &'a Arc<LNode<V>>, value: C, value_flag: Option<Flag<B>>, replace: bool) -> InsertResult<'a, B, V, H> where V: PartialEq<K> {
+pub(super) fn insert<'a, H: Hashword, F: Flagword<H>, K: 'static, V: Value, C: AsRef<K> + Into<V>, M: HasherBv<H, V>>(this: &'a Arc<LNode<V>>, value: C, value_flag: Option<Flag<H, F>>, replace: bool) -> InsertResult<'a, H, F, V, M> where V: PartialEq<K>, <F as core::convert::TryFrom<<H as core::ops::BitAnd>::Output>>::Error: core::fmt::Debug {
     match this.find(value.as_ref()) {
         FindResult::Found(reference) => if replace {
             match this.remove_from_lnode(value.as_ref()) {
@@ -88,7 +90,7 @@ pub(super) fn insert<'a, B: Bits, K: 'static, V: Value, C: AsRef<K> + Into<V>, H
             InsertResult::Found(reference)
         },
         FindResult::NotFound => {
-            lift_to_cnode_and_insert(LNodeNext::L(this.clone()), H::default().hash(&this.value), value.into(), value_flag)
+            lift_to_cnode_and_insert(LNodeNext::L(this.clone()), M::default().hash(&this.value), value.into(), value_flag)
         }
     }
 }
