@@ -1,32 +1,51 @@
 use crate::{node::{CNode, LNode, SNode}, traits::*};
 use alloc::sync::Arc;
 
+/// `BitError` enumerates possible error conditions when bitops are used "incorrectly."
+#[derive(Debug)]
+#[must_use]
+pub enum BitError {
+    /// `BitError::CountNotEqualToOne` indicates a word representing a bit contains either 2 or more bits or 0 bits.
+    CountNotEqualToOne,
+    /// `BitError::Found` indicates a bit that is supposed to be absent is present.
+    Found,
+    /// `BitError::NotFound` indicates a bit that is supposed to be present is absent.
+    NotFound,
+    /// `BitError::Range` indicates an index exceeding the word size was used.
+    Range,
+}
+
+#[must_use]
 pub(crate) enum FindResult<'a, V: Value> {
     NotFound,
     Found(&'a V),
 }
 
-pub(crate) enum InsertResult<'a, B: Bits, V: Value, H: 'static> {
+#[must_use]
+pub(crate) enum InsertResult<'a, H: Hashword, F: Flagword<H>, V: Value, M: 'static> {
     Found(&'a V),
-    InsertedC(CNode<B, V, H>, Option<&'a V>),
+    InsertedC(CNode<H, F, V, M>, Option<&'a V>),
     InsertedL(Arc<LNode<V>>, Option<&'a V>),
     InsertedS(Arc<SNode<V>>, Option<&'a V>),
 }
 
-pub(crate) enum RemoveResult<'a, B: Bits, V: Value, H: 'static> {
+#[must_use]
+pub(crate) enum RemoveResult<'a, H: Hashword, F: Flagword<H>, V: Value, M: 'static> {
     NotFound,
-    RemovedC(CNode<B, V, H>, &'a V),
+    RemovedC(CNode<H, F, V, M>, &'a V),
     RemovedL(Arc<LNode<V>>, &'a V),
     RemovedS(Arc<SNode<V>>, &'a V),
     RemovedZ(&'a V),
 }
 
+#[must_use]
 pub(crate) enum LNodeRemoveResult<'a, V: Value> {
     NotFound,
     RemovedL(Arc<LNode<V>>, &'a V),
     RemovedS(Arc<SNode<V>>, &'a V),
 }
 
+#[must_use]
 pub(crate) enum SNodeRemoveResult<'a, V: Value> {
     NotFound,
     RemovedZ(&'a V),
