@@ -8,6 +8,7 @@ struct SetEntry<V> {
 }
 
 impl <V> SetEntry<V> {
+    #[must_use]
     fn new(value: V) -> Self {
         Self {value}
     }
@@ -62,7 +63,7 @@ impl <V> HashLike<SetEntry<V>> for V {}
 /// use hash_trie::HashTrieSet;
 /// use std::{borrow::Cow, collections::hash_map::DefaultHasher};
 ///
-/// let mut hash_set: HashTrieSet<u64, String, DefaultHasher> = HashTrieSet::new();
+/// let mut hash_set: HashTrieSet<u64, u32, String, DefaultHasher> = HashTrieSet::new();
 /// let hello_world: String = "Hello, world!".into();
 ///
 /// hash_set = hash_set.insert(Cow::Borrowed(&hello_world), false).unwrap().0;
@@ -85,15 +86,16 @@ impl <V> HashLike<SetEntry<V>> for V {}
 /// }
 /// ```
 #[derive(Clone, Debug)]
-pub struct HashTrieSet <B: Bits, V: Value, H: HasherBv<B, V>> {
-    set: HashTrie<B, SetEntry<V>, H>,
+#[must_use]
+pub struct HashTrieSet <H: Hashword, F: Flagword<H>, V: Value, M: HasherBv<H, V> + 'static> where <F as core::convert::TryFrom<<H as core::ops::BitAnd>::Output>>::Error: core::fmt::Debug {
+    set: HashTrie<H, F, SetEntry<V>, M>,
 }
 
-impl <B: Bits, V: Value, H: HasherBv<B, V>> HashTrieSet<B, V, H> {
+impl <H: Hashword, F: Flagword<H>, V: Value, M: HasherBv<H, V> + 'static> HashTrieSet<H, F, V, M> where <F as core::convert::TryFrom<<H as core::ops::BitAnd>::Output>>::Error: core::fmt::Debug {
     /// Get a new, empty HashTrieSet.
     pub fn new() -> Self {
         Self {
-            set: HashTrie::<B, SetEntry<V>, H>::new()
+            set: HashTrie::<H, F, SetEntry<V>, M>::new()
         }
     }
 
@@ -114,7 +116,7 @@ impl <B: Bits, V: Value, H: HasherBv<B, V>> HashTrieSet<B, V, H> {
     }
 }
 
-impl <B: Bits, V: Value, H: HasherBv<B, V>> Default for HashTrieSet<B, V, H> {
+impl <H: Hashword, F: Flagword<H>, V: Value, M: HasherBv<H, V> + 'static> Default for HashTrieSet<H, F, V, M> where <F as core::convert::TryFrom<<H as core::ops::BitAnd>::Output>>::Error: core::fmt::Debug {
     fn default() -> Self {
         Self::new()
     }
