@@ -1,18 +1,6 @@
+use crate::result::BitError;
 use alloc::fmt::Debug;
-use core::{hash::{Hash, Hasher}, mem, ops::*};
-
-/// `BitError` enumerates possible error conditions when bitops are used "incorrectly."
-#[derive(Debug)]
-pub enum BitError {
-    /// `BitError::CountNotEqualToOne` indicates a word representing a bit contains either 2 or more bits or 0 bits.
-    CountNotEqualToOne,
-    /// `BitError::Found` indicates a bit that is supposed to be absent is present.
-    Found,
-    /// `BitError::NotFound` indicates a bit that is supposed to be present is absent.
-    NotFound,
-    /// `BitError::Range` indicates an index exceeding the word size was used.
-    Range,
-}
+use core::{convert::{TryFrom, TryInto}, hash::{Hash, Hasher}, mem, ops::*};
 
 macro_rules! bit_count_one {
     ( $bit:expr) => {
@@ -51,6 +39,7 @@ macro_rules! bit_in_range {
 /// `AsUsize` supports conversion to usize for values within the word's index range.
 pub trait AsUsize {
     /// Simply cast or convert the value to a usize.
+    #[must_use]
     fn as_usize(&self) -> usize;
 }
 impl AsUsize for u8 { fn as_usize(&self) -> usize {*self as usize} }
@@ -121,6 +110,7 @@ pub trait CountOnes {
     /// Count the number of 1s in the word using `count_ones()`.
     /// 
     /// e.g. `0b10110.count_ones_t() == 3`
+    #[must_use]
     fn count_ones_t(&self) -> usize;
 }
 impl CountOnes for u8 { fn count_ones_t(&self) -> usize {self.count_ones() as usize} }
@@ -135,6 +125,7 @@ pub trait LogB {
     /// Get the log_2 of the word size.
     /// 
     /// e.g. `u32::log_b() == 5`
+    #[must_use]
     fn log_b() -> usize;
 }
 impl LogB for u8 { fn log_b() -> usize {3} }
@@ -156,19 +147,20 @@ impl LogB for usize {
 }
 
 /// `MaskLogB` provides a mask of 1s equal to the log_2 of the word size.
-pub trait MaskLogB {
+pub trait MaskLogB<T> {
     /// Get the mask, length log_2 of the word size.
     /// 
     /// e.g. `u32::mask_log_b() == 0b11111`
-    fn mask_log_b() -> Self;
+    #[must_use]
+    fn mask_log_b() -> T;
 }
-impl MaskLogB for u8 { fn mask_log_b() -> Self {0b111} }
-impl MaskLogB for u16 { fn mask_log_b() -> Self {0b1111} }
-impl MaskLogB for u32 { fn mask_log_b() -> Self {0b11111} }
-impl MaskLogB for u64 { fn mask_log_b() -> Self {0b111111} }
-impl MaskLogB for u128 { fn mask_log_b() -> Self {0b1111111} }
-impl MaskLogB for usize {
-    fn mask_log_b() -> usize {
+impl <T: From<u8>> MaskLogB<T> for u8 { fn mask_log_b() -> T {0b111.into()} }
+impl <T: From<u8>> MaskLogB<T> for u16 { fn mask_log_b() -> T {0b1111.into()} }
+impl <T: From<u16>> MaskLogB<T> for u32 { fn mask_log_b() -> T {0b11111.into()} }
+impl <T: From<u16>> MaskLogB<T> for u64 { fn mask_log_b() -> T {0b111111.into()} }
+impl <T: From<u16>> MaskLogB<T> for u128 { fn mask_log_b() -> T {0b1111111.into()} }
+impl <T: From<u16>> MaskLogB<T> for usize {
+    fn mask_log_b() -> T {
         match mem::size_of::<usize>() {
             1 => 0b111,
             2 => 0b1111,
@@ -176,7 +168,7 @@ impl MaskLogB for usize {
             8 => 0b111111,
             16 => 0b1111111,
             _ => panic!()
-        }
+        }.into()
     }
 }
 
@@ -194,28 +186,42 @@ impl NthBit for u64 { fn nth_bit(n: usize) -> Result<Self, BitError> {bit_in_ran
 impl NthBit for u128 { fn nth_bit(n: usize) -> Result<Self, BitError> {bit_in_range!(u128, n); Ok(1_u128 << n)} }
 impl NthBit for usize { fn nth_bit(n: usize) -> Result<Self, BitError> {bit_in_range!(usize, n); Ok(1_usize << n)} }
 
-/// `Bits` lists the requirements on the hash value for the hash array mapped trie to function.
-pub trait Bits: AsUsize + BitAnd + BitContains + BitIndex + BitInsert + BitRemove + Clone + CountOnes + Debug + Default + From<<Self as BitAnd>::Output> + From<<Self as Shr<usize>>::Output> + LogB + MaskLogB + NthBit + PartialEq + Shr<usize> + Send + Sync + 'static {}
-impl <B: AsUsize + BitAnd + BitContains + BitIndex + BitInsert + BitRemove + Clone + CountOnes + Debug + Default + From<<Self as BitAnd>::Output> + From<<Self as Shr<usize>>::Output> + LogB + MaskLogB + NthBit + PartialEq + Shr<usize> + Send + Sync + 'static> Bits
-for B where B: AsUsize + BitAnd + BitContains + BitIndex + BitInsert + BitRemove + Clone + CountOnes + Debug + Default + From<<Self as BitAnd>::Output> + From<<Self as Shr<usize>>::Output> + LogB + MaskLogB + NthBit + PartialEq + Shr<usize> + Send + Sync + 'static {}
+/// `Hashword` lists the requirements on hash values.
+pub trait Hashword: BitAnd + Clone + From<<Self as Shr<usize>>::Output> + PartialEq + Shr<usize> + 'static {}
+impl <H: BitAnd + Clone + From<<Self as Shr<usize>>::Output> + PartialEq + Shr<usize>> Hashword
+for H where H: BitAnd + Clone + From<<Self as Shr<usize>>::Output> + PartialEq + Shr<usize> + 'static {}
+
+/// `Flagword` lists the requirements on CNode indices.
+pub trait Flagword<H: Hashword>: AsUsize + BitContains + BitIndex + BitInsert + BitRemove + Clone + CountOnes + Default + TryFrom<<H as BitAnd>::Output> + LogB + MaskLogB<H> + NthBit + PartialEq + 'static {}
+impl <H: Hashword, F: AsUsize + BitContains + BitIndex + BitInsert + BitRemove + Clone + CountOnes + Default + TryFrom<<H as BitAnd>::Output> + LogB + MaskLogB<H> + NthBit + PartialEq> Flagword<H>
+for F where F: AsUsize + BitContains + BitIndex + BitInsert + BitRemove + Clone + CountOnes + Default + TryFrom<<H as BitAnd>::Output> + LogB + MaskLogB<H> + NthBit + PartialEq + 'static {}
 
 /// `Value` lists the requirements on the value type for the hash array mapped trie to function.
 pub trait Value: Clone + Debug + Eq + PartialEq + Hash + Send + Sync + 'static {}
 impl <T: Clone + Debug + Eq + PartialEq + Hash + Send + Sync + 'static> Value
 for T where T: Clone + Debug + Eq + PartialEq + Hash + Send + Sync + 'static {}
 
-/// `HasherBv` provides a generalization of the Hasher trait to support different word sizes for the hash values.
-pub trait HasherBv<B, V>: Default + 'static {
-    fn hash(&self, value: &V) -> B;
-}
-impl <V: Default + 'static, H: Default + Hasher + 'static> HasherBv<u64, V> for H {
-    fn hash(&self, value: &V) -> u64 {
-        let mut hasher = H::default();
-        hasher.write(unsafe { core::slice::from_raw_parts(value as *const V as *const u8, mem::size_of::<V>()) });
-        hasher.finish()
-    }
-}
-
 /// `HashLike` provides a means to assert that two types will hash identically.
 pub trait HashLike<T> {}
 impl <T> HashLike<T> for T {}
+
+/// `HasherBv` provides a generalization of the Hasher trait to support different word sizes for the hash values.
+pub trait HasherBv<B, V>: Default + 'static {
+    #[must_use]
+    fn hash(&self, value: &V) -> B;
+}
+macro_rules! hasher_bv_impl {
+    ( $type:ty ) => {
+        impl <V: Default + Hash + 'static, H: Default + Hasher + 'static> HasherBv<$type, V> for H {
+            fn hash(&self, value: &V) -> $type {
+                let mut hasher = H::default();
+                value.hash(&mut hasher);
+                hasher.finish().try_into().unwrap()
+            }
+        }
+    };
+}
+hasher_bv_impl!(u8);
+hasher_bv_impl!(u16);
+hasher_bv_impl!(u32);
+hasher_bv_impl!(u64);
